@@ -1,12 +1,12 @@
-#' Calculates a matrix in which each column is a skewed Gaussian 
-#' 
-#' @description Calculates a matrix in which each column is a skewed Gaussian. 
+#' Calculates a matrix in which each column is a skewed Gaussian
+#'
+#' @description Calculates a matrix in which each column is a skewed Gaussian.
 #' Like \code{calcEhiergaus} from TIMP package but uses a vector not a list of parameter estimates.
 #'
 #' @param theta vector of parameter estimates
 #' @param lambda wavelengths at which to calculate model
 #'
-#' @return \code{matrix} 
+#' @return \code{matrix}
 #' @importFrom TIMP skew l2nu
 #' @export
 #'
@@ -28,30 +28,30 @@ calcE <- function(theta, lambda) {
 #' @param sim object of class \code{dat} representing data
 #' @param model object of class \code{dat} representing a model
 #' @param iter integer number of iterations
-#' @param kroncol object of class \code{logical} that is 
-#' \code{TRUE} if the \code{kroneckcol} function should be used to formulate the model and 
+#' @param kroncol object of class \code{logical} that is
+#' \code{TRUE} if the \code{kroneckcol} function should be used to formulate the model and
 #' \code{FALSE} if the standard \code{kronecker} is to be used instead
 #' @param lin defines the range to plot linearly (from -\code{lin} to +\code{lin})
 #' @param l_posk object of class \code{logical} indicating whether positivity constraints are enforced on the rate parameters
 #'
 #' @importFrom TIMP compModel
-#' @importFrom stats nls nls.control 
-#' @importFrom utils head tail 
+#' @importFrom stats nls nls.control
+#' @importFrom utils head tail
 #' @export
 #'
 spectemp <- function(sim, model, iter, kroncol=FALSE, lin=NA,l_posk=FALSE) {
-  
+
   psisim <- as.vector(sim@psi.df)
   dummy <- as.data.frame(psisim)
-  
+
   specpar <- unlist(model@specpar)
   kinpar <- model@kinpar
   seqmod <- model@seqmod
   irfpar <- model@irfpar
-  irf <- model@irf 
+  irf <- model@irf
   x2 <- sim@x2
   x <- sim@x
-  
+
   ## not using the calcEhiergaus from TIMP because it requires a list of
   ## specpar, as opposed to a vector
   if (l_posk) {
@@ -66,7 +66,7 @@ spectemp <- function(sim, model, iter, kroncol=FALSE, lin=NA,l_posk=FALSE) {
                                                irf=irf,
                                                irfpar=irfpar))
     }
-    
+
     #
     # NB warnOnly=TRUE, to return also in case of nonconvergence
     #
@@ -75,7 +75,7 @@ spectemp <- function(sim, model, iter, kroncol=FALSE, lin=NA,l_posk=FALSE) {
                 start = list(k = log(kinpar), sp = specpar, irfpar=irfpar),
                 algorithm = "plinear", trace = TRUE)
   } else {
-    
+
     if(kroncol) {
       kronform <- psisim ~ kroneckercol(A= calcE(sp, x2),
                                         B= compModel(k=k, x=x, seqmod=seqmod,
@@ -87,29 +87,29 @@ spectemp <- function(sim, model, iter, kroncol=FALSE, lin=NA,l_posk=FALSE) {
                                                irf=irf,
                                                irfpar=irfpar))
     }
-    
+
     #
     # NB warnOnly=TRUE, to return also in case of nonconvergence
     #
     onls <- nls(kronform, control = nls.control(printEval=TRUE, warnOnly=TRUE,maxiter=iter),
                 start = list(k = kinpar, sp = specpar, irfpar=irfpar),
                 algorithm = "plinear", trace = TRUE)
-    
+
   }
-  
+
   # sumonlskron <- summary(onls, correlation=TRUE)
-  # if(kroncol) { 
+  # if(kroncol) {
   #    assign("sumonlssingle",  sumonlskron, envir=.GlobalEnv)
   # } else {
   #   assign("sumonlsmultiple",  sumonlskron, envir=.GlobalEnv)
   # }
-  
+
   ## standardize the storage of par. est., assuming order is kinpar, specpar
   ## irfpar
   theta <- theta()
-  
+
   if(length(model@irfpar) > 0) {
-    pars <- head(onls$m$getPars(), length(onls$m$getPars())-2) 
+    pars <- head(onls$m$getPars(), length(onls$m$getPars())-2)
     theta@irfpar <- tail(onls$m$getPars(),2)
   } else {
     pars <- onls$m$getPars()
@@ -120,15 +120,15 @@ spectemp <- function(sim, model, iter, kroncol=FALSE, lin=NA,l_posk=FALSE) {
   } else {
     theta@kinpar <- head(pars, length(kinpar))
   }
-  
+
   #plotterforGUI(modtype="spectemp", data=sim, model=model, theta=theta, result=onls, lin = lin)
   list("theta"=theta,"onls"=onls)
-  
+
 }
 
 
 #' kroneckercol: column-wise kronecker product
-#' 
+#'
 #' @description The column-wise kronecker product is also called the Khatri–Rao product
 #'
 #' @param A numerical matrix
@@ -152,7 +152,7 @@ spectemp <- function(sim, model, iter, kroncol=FALSE, lin=NA,l_posk=FALSE) {
 #'
 #' @param x values for which to calculate a linlog axis
 #' @param mu center of axis in the orginal \code{x} axis
-#' @param alpha linear part 
+#' @param alpha linear part
 #'
 #' @return Returns matrix with new \code{x} values in first column and the corresponding labels in the second column.
 #'
@@ -162,7 +162,7 @@ spectemp <- function(sim, model, iter, kroncol=FALSE, lin=NA,l_posk=FALSE) {
   ticsl <- c(-alpha)
   tics <- c(-alpha)
   cntmin <- -alpha
-  
+
   while (cntmin > minorigx) {
     cntmin <- cntmin * 10
     ticsl <- append(ticsl, cntmin)
@@ -179,7 +179,7 @@ spectemp <- function(sim, model, iter, kroncol=FALSE, lin=NA,l_posk=FALSE) {
   ## new x values as column 1
   ## new x labels as colum 2
   ret<-cbind(tics, ticsl)
-  
+
   ret
 }
 
@@ -205,8 +205,8 @@ spectemp <- function(sim, model, iter, kroncol=FALSE, lin=NA,l_posk=FALSE) {
 "plotterforGUI" <- function(modtype="kin", X=matrix(), data, model,
                             theta=vector(), result, lin=NA, mu=0)
 {
-  
-  
+
+
   ## note that result is the return value of fitModel if modtype=="spec"
   ## or modtype == "kin", and the return value of nls otherwise
   if(!is.null(model)) {
@@ -220,21 +220,22 @@ spectemp <- function(sim, model, iter, kroncol=FALSE, lin=NA,l_posk=FALSE) {
   }
   nt <- data@nt
   nl <- data@nl
-  
+
   x <- data@x
   x2 <- data@x2
-  
+
   if(!is.null(model)) {
-    if(modtype == "kin" && length(model@irfpar) > 0) 
+    if(modtype == "kin" && length(model@irfpar) > 0)
       mu <- unlist(parEst(result,param="irfpar",dataset=1,verbose=F))[1]
-    else {if(modtype == "spectemp" && length(theta@irfpar) > 0) 
+    else {if(modtype == "spectemp" && length(theta@irfpar) > 0)
       mu <- head(theta@irfpar,1)
     else
       mu <- 0 }
   }
-  
+
   op <- par(no.readonly = TRUE)
   # CHANGE PLOT OPTIONS
+  # TODO: change plotting options to one of the alternatives, layout or split.screen.
   if(!is.null(model)) {
     if ((nt==1)||(nl==1))
     {par(mfrow = c(2, 2), oma=c(0,0,3,0))}
@@ -242,28 +243,28 @@ spectemp <- function(sim, model, iter, kroncol=FALSE, lin=NA,l_posk=FALSE) {
   } else {
     par(mfrow = c(2, 3), oma=c(0,0,3,0))
   }
-  
+
   ## get labels and time axis for linlog plots
-  
+
   if(is.na(lin)) {
-    if(!modtype == "spec") { 
-      if( (!is.null(model) && length(model@irfpar) > 0) ) 
+    if(!modtype == "spec") {
+      if( (!is.null(model) && length(model@irfpar) > 0) )
         lin <- max(pretty(abs(mu)*10))
-      else 
+      else
         lin <- max(data@x)
     }
     else
       lin <- max(data@x)
   }
-  
+
   xnew <- linloglines(x, mu=mu,alpha=lin)
   newlab <- linlogtics(x, mu=0,alpha=lin)
-  
+
   if(!is.null(model)) {
     if(!modtype == "spectemp") {
       residuals <- matrix(nrow = nt, ncol = nl)
       residlist <- result$currModel@fit@resultlist[[1]]@resid
-      for (j in 1:length(residlist)) { 
+      for (j in 1:length(residlist)) {
         if(modtype=="kin")
           residuals[, j] <- residlist[[j]]
         else
@@ -275,10 +276,10 @@ spectemp <- function(sim, model, iter, kroncol=FALSE, lin=NA,l_posk=FALSE) {
       dim(residuals) <- c(nt, nl)
     }
   }
-  
-  
-  #PLOT DATA 
-  
+
+
+  #PLOT DATA
+
   observed <- data@psi.df
   if (nt == 1) {
     plot(x=x2, y=observed,  xlab = "wavelength (nm)",ylab="",
@@ -289,7 +290,7 @@ spectemp <- function(sim, model, iter, kroncol=FALSE, lin=NA,l_posk=FALSE) {
     abline(0, 0)
   }
   else {
-    if(nl == 1) {  
+    if(nl == 1) {
       ##    linlogplot(x=x, y=observed, mu=mu, alpha=lin, xlab = "time (ps)",ylab="",               main = "Data", type = "l", xlim=c(min(x), max(x)))
       plot(x=x, y=observed, xlab = "time (ps)",ylab="",
            main = "Data", type = "l", xlim=c(min(x), max(x)))
@@ -308,8 +309,8 @@ spectemp <- function(sim, model, iter, kroncol=FALSE, lin=NA,l_posk=FALSE) {
                  main = "Data", col = diverge_hcl(40, h = c(0, 120), c =
                                                     60, l = c(45, 90), power = 1.2))
       par(mar=m)
-      
-      # PLOT SVD DATA 
+
+      # PLOT SVD DATA
       svdobserved <- svd(observed)
       plot(log10(svdobserved$d),main="log(sing val. data)",  ylab="")
       lsv1<-svdobserved$u[,1]
@@ -322,41 +323,36 @@ spectemp <- function(sim, model, iter, kroncol=FALSE, lin=NA,l_posk=FALSE) {
                  xlab = "time (ps)",type = "l",  ylab="",xlim=c(min(x), max(x)),ylim=c(min(lsv1,0),max(lsv1,0)))
       abline(0,0,lty=3)
       plot(x2,svdobserved$v[,1],main="1st RSV data",
-           xlab = "wavelength (nm)",type = "l",  ylab="")	
-      abline(0,0,lty=3)
-      
-      linlogplot(x=x,y=svdobserved$u[,2],mu=mu, alpha=lin, main="2nd LSV data",
-                 xlab = "time (ps)",type = "l",  ylab="",xlim=c(min(x), max(x)))
-      abline(0,0,lty=3)
-      plot(x2,svdobserved$v[,2],main="2nd RSV data",
-           xlab = "wavelength (nm)",type = "l",  ylab="")	
+           xlab = "wavelength (nm)",type = "l",  ylab="")
       abline(0,0,lty=3)
+
+      # moved plotting of 2nd LSV and RSV after plotting of spectra
     }
-    
+
   }
   if(!is.null(model)) {
-    if (nt > 1){  
+    if (nt > 1){
       #PLOT CONCENTRATIONS
-      
+
       if(!modtype == "spec")
-        C <- compModel(k = theta@kinpar, x = x, irfpar = theta@irfpar, 
+        C <- compModel(k = theta@kinpar, x = x, irfpar = theta@irfpar,
                        irf = model@irf, seqmod = model@seqmod)
       else { # modtype == "spec"
         C <- X
-        # assign("Cest",cbind(x, C), envir = globalenv()) 
+        # assign("Cest",cbind(x, C), envir = globalenv())
       }
-      
-      
+
+
       if(lin == 0)
         matplot(x, C,  xlab = "time (ps)", ylab="",
                 main = "Concentrations", type="l",lty=1)
       else {
-        
-        matlinlogplot(x, C, mu, lin, ylab="", xlab = "time (ps)", 
+
+        matlinlogplot(x, C, mu, lin, ylab="", xlab = "time (ps)",
                       main = "Concentrations", type="l",lty=1)
       }
       if(data@simdata)
-      {   
+      {
         if((modtype == "kin")||(modtype == "spectemp"))
         {amplitudes = data@amplitudes
         ncomp<-length(amplitudes)
@@ -370,23 +366,23 @@ spectemp <- function(sim, model, iter, kroncol=FALSE, lin=NA,l_posk=FALSE) {
       abline(0,0,lty=3)
     } else {barplot(X[1,], main = "Amplitudes",  ylab="",
                     xlab = "component",lty=1)
-    }  
-    if (nl > 1){  
+    }
+    if (nl > 1){
       #PLOT SPECTRA
-      
+
       if(modtype == "kin") {
         E <- X
-        # assign("Eest",cbind(x2, E), envir = globalenv()) 
+        # assign("Eest",cbind(x2, E), envir = globalenv())
       }
       if(modtype == "spec")
         E <- calcEhiergaus(lambda=x2, theta=theta@specpar, nupower=1)
       if(modtype == "spectemp")
         E <- calcE(lambda=x2, theta=unlist(theta@specpar))
-      
+
       matplot(x2, E, main = "Spectra",  ylab="",
               xlab = "wavelength (nm)", type="l",lty=1)
       abline(0,0,lty=3)
-      
+
       if(data@simdata)
         if(modtype == "kin")
         {    aE2<-data@E2%*%diag(amplitudes,ncomp,ncomp)
@@ -397,8 +393,18 @@ spectemp <- function(sim, model, iter, kroncol=FALSE, lin=NA,l_posk=FALSE) {
     } else {
       barplot(X[1,], main = "Amplitudes",  ylab="",
               xlab = "component",lty=1)
-    }  
-    #PLOT RESIDS 
+    }
+    # Moved 2nd LSV and RSV here:
+    if (nt > 1 && nl > 1) {
+    linlogplot(x=x,y=svdobserved$u[,2],mu=mu, alpha=lin, main="2nd LSV data",
+               xlab = "time (ps)",type = "l",  ylab="",xlim=c(min(x), max(x)))
+    abline(0,0,lty=3)
+
+    plot(x2,svdobserved$v[,2],main="2nd RSV data",
+         xlab = "wavelength (nm)",type = "l",  ylab="")
+    abline(0,0,lty=3)
+    }
+    #PLOT RESIDS
     if (nt == 1) {
       plot(x=x2, y=residuals[1,],  xlab = "wavelength (nm)", ylab="",
            main = "Residuals", type = "l",xlim=c(min(x2), max(x2)))
@@ -419,12 +425,12 @@ spectemp <- function(sim, model, iter, kroncol=FALSE, lin=NA,l_posk=FALSE) {
         image.plot(xnew, x2, residuals, ylab = "wavelength (nm)", legend.only=TRUE,
                    main = "Residuals", col = diverge_hcl(40, h = c(0, 120), c =
                                                            60, l = c(45, 90), power = 1.2))
-        par(mar=m)    
+        par(mar=m)
         svdresid <- svd(residuals)
         logsvd<-log10(svdresid$d)
         lenlogsvd<-length(logsvd)
         nsingvalres<-lenlogsvd-dim(E)[2]
-        
+
         plot(logsvd[1:nsingvalres], main="log(sing. val. resid.)", ylab="")
         linlogplot(x=x, y=svdresid$u[,1], mu=mu, alpha=lin, main="1st LSV resid.",
                    xlab = "time (ps)", type = "l",  ylab="",xlim=c(min(x), max(x)))
@@ -433,14 +439,14 @@ spectemp <- function(sim, model, iter, kroncol=FALSE, lin=NA,l_posk=FALSE) {
              xlab = "wavelength (nm)",type = "l", ylab="")
         abline(0,0,lty=3)
       }  }
-    # ADD TITLE 
+    # ADD TITLE
     if(!modtype=="spec") {
       kinest <- paste("Kin par:", toString(signif(theta@kinpar, digits=4)))
-      if(length(theta@irfpar) > 0) 
+      if(length(theta@irfpar) > 0)
         kinest <- paste(kinest, "   IRF par:",
                         toString(signif(theta@irfpar, digits=4)))
       mtext(kinest, side = 3, outer = TRUE, line = 1)
-      
+
     }
     if(!modtype=="kin") {
       specest <- paste("Spec par:", toString(signif(unlist(theta@specpar),
@@ -453,16 +459,16 @@ spectemp <- function(sim, model, iter, kroncol=FALSE, lin=NA,l_posk=FALSE) {
   # try 20111104
   #tkdestroy(winmodel)
   #this only kills one winmodel ...
-  
+
 }
 
 #' Simulate data
 #'
 #' @description Calculates an object of class "kin". <TODO>
-#' 
+#'
 #' @author Katharine M. Mullen
-#' @author Ivo H. M. van Stokkum 
-#' 
+#' @author Ivo H. M. van Stokkum
+#'
 #' @param kinpar vector of rate constants
 #' @param tmax last time point
 #' @param deltat time step
@@ -502,47 +508,47 @@ spectemp <- function(sim, model, iter, kroncol=FALSE, lin=NA,l_posk=FALSE) {
 #' @export
 #'
 "simndecay_gen_paramGUI" <-
-  function (kinpar, tmax, deltat, specpar=vector(), lmin, lmax, deltal, 
+  function (kinpar, tmax, deltat, specpar=vector(), lmin, lmax, deltal,
             sigma, irf = FALSE, irfpar = vector(), seqmod = FALSE, dispmu
-            = FALSE, nocolsums=FALSE, 
-            disptau = FALSE, parmu = list(), partau = vector(), lambdac = 0, 
-            fullk = FALSE, kmat = matrix(), jvec = vector(), specfun = "gaus", 
-            nupow = 1, irffun = "gaus", kinscal = vector(), 
+            = FALSE, nocolsums=FALSE,
+            disptau = FALSE, parmu = list(), partau = vector(), lambdac = 0,
+            fullk = FALSE, kmat = matrix(), jvec = vector(), specfun = "gaus",
+            nupow = 1, irffun = "gaus", kinscal = vector(),
             lightregimespec = list(),
             specdisp = FALSE, specdisppar=list(), parmufunc = "exp",
-            specdispindex = list(), amplitudes = vector(),specref=0,nosiminfo=FALSE) 
+            specdispindex = list(), amplitudes = vector(),specref=0,nosiminfo=FALSE)
   {
     if (tmax>0) { x <- seq(0, tmax, deltat)} else { x<-c(1) }
     nt <- length(x)
     ncomp <- length(kinpar)
     x2 <- seq(lmin, lmax, deltal)
     nl <- length(x2)
-    
+
     if(specdisp){
       ## store all the spectra; could do it otherwise if mem. is an issue
       EList <- list()
       for (i in 1:nt) {
-        sp <- specparF(specpar = specpar, 
-                       xi = x[i], 
-                       i = i, specref = specref, 
-                       specdispindex = specdispindex, 
+        sp <- specparF(specpar = specpar,
+                       xi = x[i],
+                       i = i, specref = specref,
+                       specdispindex = specdispindex,
                        specdisppar = specdisppar,
                        parmufunc = parmufunc)
         EList[[i]] <- calcEhiergaus(sp, x2, nupow)
       }
     }
-    else 
+    else
       if (lmin==lmax) {E2<-matrix(1,nrow = 1, ncol = ncomp)
       # TODO: set modType to 0?
       }else{
         E2 <- calcEhiergaus(specpar, x2, nupow)}
-    
+
     if (!(dispmu || disptau)) {
       if (nt==1){
         C2<- matrix(amplitudes,nrow = 1, ncol = ncomp)
         # TODO: set modType to 0?
       } else {
-        C2 <- compModel(k = kinpar, x = x, irfpar = irfpar, irf = irf, 
+        C2 <- compModel(k = kinpar, x = x, irfpar = irfpar, irf = irf,
                         seqmod = seqmod, fullk = fullk, kmat = kmat,
                         jvec = jvec,amplitudes = amplitudes,
                         lightregimespec = lightregimespec,
@@ -555,16 +561,16 @@ spectemp <- function(sim, model, iter, kroncol=FALSE, lin=NA,l_posk=FALSE) {
           psisim[i,] <- t(as.matrix(C2[i, ])) %*% t(EList[[i]])
         }
       }
-      else 
+      else
         psisim <- C2 %*% t(E2)
     }
     else {
       psisim <- matrix(nrow = nt, ncol = nl)
       for (i in 1:nl) {
-        irfvec <- irfparF(irfpar, lambdac, x2[i], i, dispmu, 
+        irfvec <- irfparF(irfpar, lambdac, x2[i], i, dispmu,
                           parmu, disptau, partau, "", "", "gaus")
-        
-        C2 <- compModel(k = kinpar, x = x, irfpar = irfpar, irf = irf, 
+
+        C2 <- compModel(k = kinpar, x = x, irfpar = irfpar, irf = irf,
                         seqmod = seqmod, fullk = fullk, kmat = kmat,
                         jvec = jvec,amplitudes = amplitudes,
                         lightregimespec = lightregimespec,
@@ -575,17 +581,17 @@ spectemp <- function(sim, model, iter, kroncol=FALSE, lin=NA,l_posk=FALSE) {
     dim(psisim) <- c(nt * nl, 1)
     psi.df <- psisim + sigma * rnorm(nt * nl)
     dim(psi.df) <- c(nt, nl)
-    
+
     if (nosiminfo){
-      dat(psi.df = psi.df, x = x, nt = nt, x2 = x2, nl = nl, 
+      dat(psi.df = psi.df, x = x, nt = nt, x2 = x2, nl = nl,
           simdata = FALSE)
     }
     else{
-      kin(psi.df = psi.df, x = x, nt = nt, x2 = x2, nl = nl, C2 = C2, 
-          E2 = E2, kinpar = kinpar, specpar = specpar, 
-          seqmod = seqmod, irf = irf, irfpar = irfpar, 
-          dispmu = dispmu, disptau = disptau, parmu = parmu, partau = partau, 
-          lambdac = lambdac, simdata = TRUE, fullk = fullk, kmat = kmat, 
+      kin(psi.df = psi.df, x = x, nt = nt, x2 = x2, nl = nl, C2 = C2,
+          E2 = E2, kinpar = kinpar, specpar = specpar,
+          seqmod = seqmod, irf = irf, irfpar = irfpar,
+          dispmu = dispmu, disptau = disptau, parmu = parmu, partau = partau,
+          lambdac = lambdac, simdata = TRUE, fullk = fullk, kmat = kmat,
           jvec = jvec,amplitudes = amplitudes)
     }
   }
